==> cloudnary_flutter-0.0.4.tar.gz: android/src/main/kotlin/com/clodnary/cloudnary_flutter/CloudnaryFlutterPlugin.kt <==
package com.clodnary.cloudnary_flutter

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.util.Log
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import com.cloudinary.*
import com.cloudinary.android.MediaManager
import com.cloudinary.android.callback.ErrorInfo
import com.cloudinary.android.callback.UploadCallback
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding


/** CloudnaryFlutterPlugin */
class CloudnaryFlutterPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var activity: Activity

  companion object{
    var globalResult:Result? = null
    var cloudName:String = ""
    var api:String = ""
    var apiSecret:String = ""
    var publicId:String = ""
    var notificationUrl:String = ""
    var path:String = ""
  }

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "cloudnary_flutter")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {

    if (call.method == "uploadToCloudnary") {
      cloudName = call.argument<String>("cloudName").toString()
      api = call.argument<String>("api").toString()
      apiSecret = call.argument<String>("apiSecret").toString()
      publicId = call.argument<String>("publicId").toString()
      notificationUrl = call.argument<String>("notificationUrl").toString()
      path = call.argument<String>("path").toString()
      globalResult = result
      activity.startActivity(Intent(activity, ImageUploading::class.java))
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onDetachedFromActivity() {
    TODO("Not yet implemented")
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    TODO("Not yet implemented")
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivityForConfigChanges() {
    TODO("Not yet implemented")
  }

}

==> cloudnary_flutter-0.0.6.tar.gz: android/src/main/kotlin/com/clodnary/cloudnary_flutter/CloudnaryFlutterPlugin.kt <==
package com.clodnary.cloudnary_flutter

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.util.Log
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import com.cloudinary.*
import com.cloudinary.android.MediaManager
import com.cloudinary.android.callback.ErrorInfo
import com.cloudinary.android.callback.UploadCallback
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import org.json.JSONObject


/** CloudnaryFlutterPlugin */
class CloudnaryFlutterPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var activity: Activity

  companion object{
    var globalResult:Result? = nullCallbackImpl
    var cloudName:String = ""
    var api:String = ""
    var apiSecret:String = ""
    var publicId:String = ""
    var notificationUrl:String = ""
    var path:String = ""
  }

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "cloudnary_flutter")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {

    if (call.method == "uploadToCloudnary") {

      cloudName = call.argument<String>("cloudName").toString()
      api = call.argument<String>("api").toString()
      apiSecret = call.argument<String>("apiSecret").toString()
      publicId = call.argument<String>("publicId").toString()
      notificationUrl = call.argument<String>("notificationUrl").toString()
      path = call.argument<String>("path").toString()
      globalResult = result
      activity.startActivity(Intent(activity, ImageUploading::class.java))
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onDetachedFromActivity() {
    TODO("Not yet implemented")
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    TODO("Not yet implemented")
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivityForConfigChanges() {
    TODO("Not yet implemented")
  }

}
